@@ -12,7 +12,7 @@ import requests
 import torch
 from tqdm import tqdm
 
-from ultralytics.yolo.utils import LOGGER
+from ultralytics.yolo.utils import LOGGER, checks, emojis, is_online
 
 GITHUB_ASSET_NAMES = [f'yolov8{size}{suffix}.pt' for size in 'nsmlx' for suffix in ('', '6', '-cls', '-seg')] + \
                      [f'yolov5{size}u.pt' for size in 'nsmlx'] + \
@@ -87,7 +87,7 @@ def safe_download(url,
             try:
                 if curl or i > 0:  # curl download with retry, continue
                     s = 'sS' * (not progress)  # silent
-                    r = subprocess.run(['curl', '-#', f'-{s}L', url, '-o', f, '--retry', '9', '-C', '-']).returncode
+                    r = subprocess.run(['curl', '-#', f'-{s}L', url, '-o', f, '--retry', '3', '-C', '-']).returncode
                     assert r == 0, f'Curl return value {r}'
                 else:  # urllib download
                     method = 'torch'
@@ -95,14 +95,14 @@ def safe_download(url,
                         torch.hub.download_url_to_file(url, f, progress=progress)
                     else:
                         from ultralytics.yolo.utils import TQDM_BAR_FORMAT
-                        with request.urlopen(url) as response, tqdm(total=int(response.getheader("Content-Length", 0)),
+                        with request.urlopen(url) as response, tqdm(total=int(response.getheader('Content-Length', 0)),
                                                                     desc=desc,
                                                                     disable=not progress,
                                                                     unit='B',
                                                                     unit_scale=True,
                                                                     unit_divisor=1024,
                                                                     bar_format=TQDM_BAR_FORMAT) as pbar:
-                            with open(f, "wb") as f_opened:
+                            with open(f, 'wb') as f_opened:
                                 for data in response:
                                     f_opened.write(data)
                                     pbar.update(len(data))
@@ -112,11 +112,13 @@ def safe_download(url,
                         break  # success
                     f.unlink()  # remove partial downloads
             except Exception as e:
-                if i >= retry:
-                    raise ConnectionError(f'❌  Download failure for {url}') from e
+                if i == 0 and not is_online():
+                    raise ConnectionError(emojis(f'❌  Download failure for {url}. Environment is not online.')) from e
+                elif i >= retry:
+                    raise ConnectionError(emojis(f'❌  Download failure for {url}. Retry limit reached.')) from e
                 LOGGER.warning(f'⚠️ Download failure, retrying {i + 1}/{retry} {url}...')
 
-    if unzip and f.exists() and f.suffix in {'.zip', '.tar', '.gz'}:
+    if unzip and f.exists() and f.suffix in ('.zip', '.tar', '.gz'):
         unzip_dir = dir or f.parent  # unzip to dir if provided else unzip in place
         LOGGER.info(f'Unzipping {f} to {unzip_dir}...')
         if f.suffix == '.zip':
@@ -132,8 +134,7 @@ def safe_download(url,
 
 def attempt_download_asset(file, repo='ultralytics/assets', release='v0.0.0'):
     # Attempt file download from GitHub release assets if not found locally. release = 'latest', 'v6.2', etc.
-    from ultralytics.yolo.utils import SETTINGS
-    from ultralytics.yolo.utils.checks import check_yolov5u_filename
+    from ultralytics.yolo.utils import SETTINGS  # scoped for circular import
 
     def github_assets(repository, version='latest'):
         # Return GitHub repo tag and assets (i.e. ['yolov8n.pt', 'yolov8s.pt', ...])
@@ -144,7 +145,7 @@ def attempt_download_asset(file, repo='ultralytics/assets', release='v0.0.0'):
 
     # YOLOv3/5u updates
     file = str(file)
-    file = check_yolov5u_filename(file)
+    file = checks.check_yolov5u_filename(file)
     file = Path(file.strip().replace("'", ''))
     if file.exists():
         return str(file)
@@ -171,7 +172,7 @@ def attempt_download_asset(file, repo='ultralytics/assets', release='v0.0.0'):
                 tag, assets = github_assets(repo)  # latest release
             except Exception:
                 try:
-                    tag = subprocess.check_output(["git", "tag"]).decode().split()[-1]
+                    tag = subprocess.check_output(['git', 'tag']).decode().split()[-1]
                 except Exception:
                     tag = release
 
